# ProofOfPy

Coming soon ...

## Getting Started

### Prerequisites

- Python 3.10 or later.
- Pip (Python package installer)

### Installation

```sh
pip install proof-of-py
```


## License

This project is licensed under the MIT License.
